Description: The Nevada Judiciary website contains regularly updated information dealing with the Supreme Court of Nevada, Administrative Offices of the Court, among others. Recent decisions, judiciary news, schedules, oral argument calendars, statistics, court sponsored committees and programs and publications can be viewed on this site.
Keywords: nevada, supreme, court, courts, washoe county, clerk, courtroom, phrases, municipal, law library, district, justice, administrative, judiciary, rules, civil, procedure, expressions, federal, justice, family, cases, case, report, branch, judicial, opinions, argument, settlement, judges, bar, exam, washoe, county

Mindful Images Photography

# Advance Opinions

Disclaimer: This information is prepared as an informational service only and should not be relied upon as an official record of action. For official records, please refer to the printed version of the appropriate official publication which may be obtained from the Clerk of the Supreme Court of Nevada (775) 684-1600.

Advance Opinions RSS Feed | Subscribe |

##### Click here for Order Form for Advance Sheets

Advance No. | Case Number | Running Title | Date
58 | 63737 | Johnson v. State | Jul 30, 2015
57 | 65666 | Double Diamond v. Second Jud. Dist. Ct. | Jul 30, 2015
56 | 64913 | State v. Harris | Jul 30, 2015
55 | 62745 | In re Montierth | Jul 30, 2015
54 | 61103 | Torres v. Nev. Direct Ins. Co. | Jul 30, 2015
53 | 65242 | Ford v. Branch Banking & Trust Co. | Jul 23, 2015
52 | 64135 | Barral v. State | Jul 23, 2015
51 | 62059 | Anderson v. Sanchez | Jul 23, 2015
50 | 62792 | Sanders v. Sears-Page | Jul 16, 2015
49 | 64539 | Gonzales v. State | Jul 02, 2015
48 | 65429 | State v. Beaudion | Jul 02, 2015
47 | 63810 | D & D Tire v. Ouellette | Jul 02, 2015
46 | 63492 | Biscay v. MGM Resorts Int'l | Jul 02, 2015
45 | 63731 | Davis v. Ewalefo | Jul 02, 2015
44 | 61553 | C. Nicholas Pereos, Ltd. v. Bank of Am. | Jul 02, 2015
43 | 64260 | Alper v. Eighth Jud. Dist. Ct. | Jun 25, 2015
42 | 64064 | State, Dep't of Taxation v. Kawahara | Jun 25, 2015
41 | 63179 | NDOT v. Eighth Jud. Dist. Ct. | Jun 25, 2015
40 | 56548 | Burnside v. State | Jun 25, 2015
39 | 55173 | Lisle v. State | Jun 25, 2015
38 | 62189 | Excellence Cmty. Mgmt. v. Gilmore | Jun 25, 2015
37 | 64750 | Berry v. Feil | Jun 11, 2015
36 | 58711 | Rimer v. State | Jun 11, 2015
35 | 57956 | Gov't of Marinduque v. Placer Dome, Inc. | Jun 11, 2015
34 | 62878 | Nutton v. Sunset Station, Inc. | Jun 11, 2015
33 | 61567 | Fulbrook v. Allstate Ins. Co. | Jun 04, 2015
32 | 64287 | Sharpe v. State | Jun 04, 2015
31 | 63980 | Logan v. Abe | Jun 04, 2015
30 | 63176 | Jennifer L. v. Eighth Jud. Dist. Ct. | Jun 04, 2015
29 | 62840 | Catholic Diocese, Green Bay v. John Doe 119 | May 28, 2015
28 | 60944 | Weddell v. Sharp | May 28, 2015
27 | 64215 | Guitron v. State | May 21, 2015
26 | 63274 | Manning v. State | May 07, 2015
25 | 64473 | Nev. Dep't of Corrs. v. York Claims Servs. | May 07, 2015
24 | 63683 | In re L.A.W. | May 07, 2015
23 | 63747 | Munoz v. Branch Banking | Apr 30, 2015
22 | 63644 | Veil v. Bennett | Apr 30, 2015
21 | 63076 | Mitchell v. Eighth Jud. Dist. Ct. | Apr 30, 2015
20 | 59638 | Branch Banking v. Windhaven & Tollway, LLC | Apr 30, 2015
19 | 63896 | Brown v. Eddie World, Inc. | Apr 16, 2015
18 | 64623 | Coyote Springs Inv. v. Eighth Jud. Dist. Ct. | Apr 02, 2015
17 | 58519 | Hohenstein v. State, Emp't Sec. Div. | Apr 02, 2015
16 | 65000 | Pitmon v. State | Mar 26, 2015
15 | 63382 | Cadle Co. v. Woods & Erickson, LLP | Mar 26, 2015
14 | 62308 | Bluestein v. Bluestein | Mar 26, 2015
13 | 61059 | Bullion Monarch v. Barrick Goldstrike | Mar 26, 2015
12 | 66876 | Breeden v. Eighth Jud. Dist. Ct. | Mar 05, 2015
11 | 63092 | JED Prop. v. Coastline RE Holdings NV Corp. | Mar 05, 2015
10 | 62864 | LVMPD v. Blackjack Bonding | Mar 05, 2015
9 | 62112 | U.S. Bank Nat'l Ass'n v. Palmilla Dev. Co. | Mar 05, 2015
8 | 63284 | In re Estate of Murray | Mar 05, 2015
7 | 59815 | Zahavi v. State | Feb 26, 2015
6 | 58904 | Martinorellan v. State | Feb 26, 2015
5 | 65122 | Fulbright & Jaworski v. Eighth Jud. Dist. Ct. | Feb 05, 2015
4 | 64381 | Jones v. State, Bd. of Med. Exam'rs | Feb 05, 2015
3 | 62107 | Abarra v. State of Nevada | Feb 05, 2015
2 | 61946 | Torres v. State | Jan 29, 2015
1 | 55220 | Buzz Stew, LLC v. City of N. Las Vegas | Jan 29, 2015
100 | 65934 | City of Reno v. IAFF, Local 731 | Dec 31, 2014
99 | 62327 | Stockmeier v. Green | Dec 31, 2014
98 | 62111 | Sadler v. PacifiCare of Nev. | Dec 31, 2014
97 | 63787 | Brant v. State | Dec 24, 2014
96 | 62606 | First Fin. Bank v. Lane | Dec 24, 2014
95 | 59639 | Fed. Ins. Co. v. Coast Converters | Dec 24, 2014
94 | 62748 | Nev. Ass'n Servs. v. Eighth Jud. Dist. Ct. | Dec 04, 2014
93 | 61193 | Sierra Pac. Power v. State, Dep't of Tax. | Dec 04, 2014
92 | 58176 | In re Cay Clubs | Dec 04, 2014
91 | 63311 | In re Parental Rights as to A.L. | Nov 13, 2014
90 | 62888 | State, Dep't of Bus. & Indus. v. Check City | Nov 13, 2014
89 | 65383 | Valdez v. Cox Commc'ns Las Vegas | Nov 06, 2014
88 | 59309 | FDIC v. Rhodes | Oct 30, 2014
87 | 59214 | Terry v. Sapphire Gentlemen's Club | Oct 30, 2014
86 | 61558 | Oxbow Constr. v. Eighth Jud. Dist. Ct. | Oct 16, 2014
85 | 61348 | Byars v. State | Oct 16, 2014
84 | 59319 | D.R. Horton, Inc. v. Betsinger | Oct 16, 2014
83 | 61233 | Mason-McDuffie Real Estate v. Villa Fiore | Oct 02, 2014
82 | 62343 | Buchanan v. State | Oct 02, 2014
80 | 62666 | Renown Reg'l Med. v. Second Jud. Dist. Ct. | Oct 02, 2014
79 | 62654 | Henson v. Henson | Oct 02, 2014
78 | 60478 | Guilfoyle v. Olde Monmouth Stock Transfer | Oct 02, 2014
77 | 60172 | Artiga-Morales v. State | Oct 02, 2014
76 | 56721 | Watson v. State | Oct 02, 2014
75 | 63078 | SFR Invs. Pool 1 v. U.S. Bank | Sep 18, 2014
74 | 60050 | Zohar v. Zbiegien | Sep 18, 2014
73 | 60037 | Deja Vu Showgirls v. State, Dep't of Tax. | Sep 18, 2014
72 | 59752 | Deja Vu Showgirls v. State, Dep't of Tax. | Sep 18, 2014
71 | 53264 | Franchise Tax Bd. of Cal. v. Hyatt | Sep 18, 2014
70 | 62819 | Major v. State | Aug 28, 2014
69 | 63444 | Las Vegas Sands v. Eighth Jud. Dist. Ct. | Aug 07, 2014
68 | 61767 | Brady Vorwerck v. New Albertson's | Aug 07, 2014
67 | 61820 | Greenberg Traurig v. Frias Holding Co. | Aug 07, 2014
66 | 58530 | City of N. Las Vegas v. 5th & Centennial | Aug 07, 2014
65 | 63871 | Barrett v. Eighth Jud. Dist. Ct. | Aug 07, 2014
64 | 62578 | Campos-Garcia v. Johnson | Aug 07, 2014
63 | 62160 | In re Irrevocable Trust Agreement of 1979 | Aug 07, 2014
62 | 61978 | Byrd Underground, L.L.C. v. Angaur, L.L.C. | Aug 07, 2014
61 | 62944 | Las Vegas Sands v. Eighth Jud. Dist. Ct. | Aug 07, 2014
60 | 60065 | Brown v. McDaniel | Aug 07, 2014
59 | 65737 | Imperial Credit v. Eighth Jud. Dist. Ct. | Aug 07, 2014
58 | 62768 | Wood v. Germann | Aug 07, 2014
57 | 59210 | Simmons Self-Storage v. Rib Roof, Inc. | Aug 07, 2014
46 | 59630 | FCH1, L.L.C. v. Rodriguez | Oct 02, 2014

#### Appellate Courts Decisions

- Advance Opinions
- Forthcoming Opinions
- Nevada Reports
- Supreme Court Unpublished Orders
- Court of Appeals Unpublished Orders

Privacy Policy | Site Map | Back to Top ↑